@@ -1,6 +1,6 @@
 //!
 //! # Constants
-//! 
+//!
 //! This file contains many physical constants useful for scientific applications.
 //! They are stored as `f64` to guarantee maximum precision, most are castable to `f32`.
 //!
@@ -45,6 +45,12 @@ pub const EARTH_RADIUS: f64 = 6_378_100.0;
 /// - Unit: `m3.s-2`
 pub const EARTH_GM: f64 = 3.986_004e14;
 
+/// # Earth Bond albedo
+///
+/// - Value: 0.306
+/// - Unit: /
+pub const EARTH_ALB: f64 = 0.306;
+
 /// # Jupiter mass
 ///
 /// - Value: 1.898_124_6×10²⁷
@@ -81,6 +87,12 @@ pub const SUN_RADIUS: f64 = 695_700_000.0;
 /// - Unit: `m3.s-2`
 pub const SUN_GM: f64 = 1.327_124_4e20;
 
+/// # Sun effective temperature
+///
+/// - Value: 5772
+/// - Unit: `K`
+pub const SUN_TEFF: f64 = 5772.0;
+
 /// # Sun luminosity
 ///
 /// - Value: 3.828×10²⁶
@@ -179,10 +191,10 @@ pub const Z_0: f64 = 376.730_313_668;
 // Defined
 
 /// # Euler-Mascheroni constant (γ)
-/// 
+///
 /// - Value: 0.577 215 664 901 532 860 606 512 090 082 402 431 042 159 335 939 92
 /// - Unit: /
-/// 
+///
 /// Not to be confused with Euler's number 2.71... (in standard consts of Rust).
 pub const EULER_MASCHERONI: f64 = 0.577_215_664_901_532_860_606_512_090_082_402_431_042_159_335_939_92;
 
@@ -293,3 +305,90 @@ pub const SIGMA_SB: f64 = 5.670_374_419e-8;
 pub const SIGMA_T: f64 = 6.652_458_73e-29;
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+// Scales
+
+// Multiples
+
+/// # 1e24
+/// 1 000 000 000 000 000 000 000 000
+pub const YOTTA: f64 = 1e24;
+
+/// # 1e21
+/// 1 000 000 000 000 000 000 000
+pub const ZETTA: f64 = 1e21;
+
+/// # 1e18
+/// 1 000 000 000 000 000 000
+pub const EXA: f64 = 1e18;
+
+/// # 1e15
+/// 1 000 000 000 000 000
+pub const PETA: f64 = 1e15;
+
+/// # 1e12
+/// 1 000 000 000 000
+pub const TERA: f64 = 1e12;
+
+/// # 1e9
+/// 1 000 000 000
+pub const GIGA: f64 = 1e9;
+
+/// # 1e6
+/// 1 000 000
+pub const MEGA: f64 = 1e6;
+
+/// # 1e3
+/// 1 000
+pub const KILO: f64 = 1e3;
+
+/// # 1e2
+/// 100
+pub const HECTO: f64 = 1e2;
+
+/// # 1e1
+/// 10
+pub const DECA: f64 = 1e1;
+
+// Submultiples
+
+/// # 1e-1
+/// 0.1
+pub const DECI: f64 = 1e-1;
+
+/// # 1e-2
+/// 0.01
+pub const CENTI: f64 = 1e-2;
+
+/// # 1e-3
+/// 0.001
+pub const MILLI: f64 = 1e-3;
+
+/// # 1e-6
+/// 0.000 001
+pub const MICRO: f64 = 1e-6;
+
+/// # 1e-9
+/// 0.000 000 001
+pub const NANO: f64 = 1e-9;
+
+/// # 1e-12
+/// 0.000 000 000 001
+pub const PICO: f64 = 1e-12;
+
+/// # 1e-15
+/// 0.000 000 000 000 001
+pub const FEMTO: f64 = 1e-15;
+
+/// # 1e-18
+/// 0.000 000 000 000 000 001
+pub const ATTO: f64 = 1e-18;
+
+/// # 1e-21
+/// 0.000 000 000 000 000 000 001
+pub const ZEPTO: f64 = 1e-21;
+
+/// # 1e-24
+/// 0.000 000 000 000 000 000 000 001
+pub const YOCTO: f64 = 1e-24;
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
