@@ -7,31 +7,34 @@
 //! - theta: azimuth (longitude) of the point, `[0, 2π[`
 //! - phi: elevation (latitude) of the point, `[0, π[`
 //! 
-//! Support conversion to and from Cartesian coordinates.
+//! Support conversion to and from Cartesian and Cylindrical coordinates.
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-use std::f64::consts::{
-    PI,
-    TAU
+use std::f64::consts::{         // Using std lib constants
+    PI,                         // Pi
+    TAU                         // Tau
 };
 
-use std::ops::{     // Implementing basic operations
-    Add,            // Addition
-    Sub,            // Subtraction
-    Mul,            // Multiplication
-    MulAssign,      // Assigning multiplication
-    Div,            // Division
-    DivAssign,      // Assigning division
-    Neg             // Negation
+use std::ops::{                 // Implementing basic operations
+    Add,                        // Addition
+    Sub,                        // Subtraction
+    Mul,                        // Multiplication
+    MulAssign,                  // Assigning multiplication
+    Div,                        // Division
+    DivAssign,                  // Assigning division
+    Neg                         // Negation
 };
 
-use std::fmt::{     // Formatter display
-    Display,        // The display itself
-    Result as DRes  // The associated result
+use std::fmt::{                 // Formatter display
+    Display,                    // The display itself
+    Result as DRes              // The associated result
 };
 
-use super::cartesian::Cartesian;
+use super::{                    // Using parts from the crate
+    cartesian::Cartesian,       // Cartesian coordinates
+    cylindrical::Cylindrical    // Cylindrical coordinates
+};
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -48,12 +51,12 @@ pub struct Spherical {
     pub phi: f64
 }
 
-/// # Display for Cartesian
+/// # Display for Spherical
 /// 
-/// Simply shows each value associated to an axis.
+/// Simply shows each value.
 impl Display for Spherical {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> DRes {
-        write!(f, "r={} :: theta={} :: phi={}", self.r, self.theta, self.phi)?;
+        write!(f, "r={} :: theta={}° :: phi={}°", self.r, self.theta.to_degrees(), self.phi.to_degrees())?;
         Ok(())
     }
 }
@@ -72,13 +75,17 @@ impl Spherical {
     /// assert_eq!(m, n);
     /// assert_eq!(n, d);
     /// ```
-    pub fn new() -> Self {
-        Self::default()
+    pub const fn new() -> Self {
+        Self {
+            r: 0.0,
+            theta: 0.0,
+            phi: 0.0
+        }
     }
 
     /// # From the point
     /// 
-    /// Creates a Cartesian struct from three given points in space.
+    /// Creates a Spherical struct from three given points in space.
     /// 
     /// ```
     /// # use scilib::coordinate::spherical::Spherical;
@@ -98,7 +105,7 @@ impl Spherical {
 
     /// # From the point (degrees)
     /// 
-    /// Creates a Cartesian struct from three given points in space, with the angles in degrees.
+    /// Creates a SPherical struct from three given points in space, with the angles in degrees.
     /// 
     /// ```
     /// # use scilib::coordinate::spherical::Spherical;
@@ -118,6 +125,28 @@ impl Spherical {
         }
     }
 
+    /// # From another coordinate system
+    /// 
+    /// Creates an Spherical struct from another coordinate system. Calls the `Into<Spherical>` method,
+    /// which is verified in its implementation.
+    /// 
+    /// ```
+    /// # use scilib::coordinate::cartesian::Cartesian;
+    /// # use scilib::coordinate::spherical::Spherical;
+    /// # use scilib::coordinate::cylindrical::Cylindrical;
+    /// let ca: Cartesian = Cartesian::from(0, 12, 3.2);
+    /// let cy: Cylindrical = Cylindrical::from_degree(1.2, 32, -3);
+    /// let res1: Spherical = Spherical::from_coord(ca);
+    /// let res2: Spherical = Spherical::from_coord(cy);
+    /// 
+    /// assert_eq!(res1, ca.into());
+    /// assert_eq!(res2, cy.into());
+    /// ```
+    pub fn from_coord<T>(c: T) -> Self
+    where T: Into<Self> {
+        c.into()
+    }
+
     /// # Distance between two points
     /// 
     /// ```
@@ -171,12 +200,42 @@ impl Into<Cartesian> for Spherical {
     }
 }
 
+/// # Conversion to cylindrical coordinates
+/// 
+/// ```
+/// # use scilib::coordinate::cylindrical::Cylindrical;
+/// # use scilib::coordinate::spherical::Spherical;
+/// let s = Spherical::from_degree(5, 60, 30);
+/// let conv: Cylindrical = s.into();
+/// let expected = Cylindrical::from_degree(2.5, 60, 4.330127019);
+/// 
+/// assert!((conv.r - expected.r).abs() < 1.0e-15);
+/// assert_eq!(conv.theta, expected.theta);
+/// assert!((conv.z - expected.z).abs() < 1.0e-9);
+/// 
+/// let s = Spherical::from_degree(4, 30, 60);
+/// let conv: Cylindrical = s.into();
+/// let expected = Cylindrical::from_degree(3.464101615, 30, 2);
+/// assert!((conv.r - expected.r).abs() < 1.0e-9);
+/// assert_eq!(conv.theta, expected.theta);
+/// assert!((conv.z - expected.z).abs() < 1.0e-9);
+/// ```
+impl Into<Cylindrical> for Spherical {
+    fn into(self) -> Cylindrical {
+        Cylindrical {
+            r: self.r * self.phi.sin(),
+            theta: self.theta,
+            z: self.r * self.phi.cos()
+        }
+    }
+}
+
 /// # Addition
 /// 
 /// Converts the coordinate in cartesian for addition, then returns them as spherical.
-impl Add for Spherical {
+impl<T: Into<Cartesian>> Add<T> for Spherical {
     type Output = Self;
-    fn add(self, rhs: Self) -> Self::Output {
+    fn add(self, rhs: T) -> Self::Output {
         let s: Cartesian = self.into();
         let r: Cartesian = rhs.into();
         (s + r).into()
@@ -186,9 +245,9 @@ impl Add for Spherical {
 /// # Subtraction
 /// 
 /// Converts the coordinate in cartesian for subtraction, then returns them as spherical.
-impl Sub for Spherical {
+impl<T: Into<Cartesian>> Sub<T> for Spherical {
     type Output = Self;
-    fn sub(self, rhs: Self) -> Self::Output {
+    fn sub(self, rhs: T) -> Self::Output {
         let s: Cartesian = self.into();
         let r: Cartesian = rhs.into();
         (s - r).into()
@@ -312,10 +371,10 @@ impl<T: Into<f64>> DivAssign<T> for Spherical {
 /// Going to the opposite point.
 /// 
 /// ```
-/// # use scilib::coordinate::cartesian::Cartesian;
-/// let c1 = Cartesian::from(-2, 5, 6.0);
+/// # use scilib::coordinate::spherical::Spherical;
+/// let c1 = Spherical::from_degree(2, 60, 30);
 /// let c2 = -c1;
-/// let expected = Cartesian::from(2, -5.0, -6);
+/// let expected = Spherical::from_degree(2, 240, 150);
 /// 
 /// assert_eq!(c2, expected);
 /// ```
