@@ -1,15 +1,20 @@
 //!
 //! # Bessel functions
 //! 
-//! The Bessel functions are the solution to the [Bessel differential equation](https://en.wikipedia.org/wiki/Bessel_function#Spherical_Bessel_functions).
+//! The [Bessel functions](https://en.wikipedia.org/wiki/Bessel_function) are the solution to the Bessel differential equation.
 //! There are multiple variants of these solutions, and this sub-module provides functions for all of them.
 //! 
+//! They are used to solve Bessel's differential equation:
+//! $$
+//! x^2\frac{d^2y}{dx^2} + x\frac{dy}{dx} + (x^2 - \alpha^2)y = 0
+//! $$
+//! 
 //! ## First kind: J
 //! 
 //! The Jn(x) function is the simplest solution to Bessel's equation. The most generalized case is for
 //! a real index `n` and a complex number `x`, which is possible with this crate. Additionally, two methods are
 //! provided for this equation, one for a integer order (named `j`) and one for a real order (named `jf`). The integer
-//! order one is limited but is faster than it's counterpart. The real order function is slower, but can compute any
+//! order one is limited but is faster than its counterpart. The real order function is slower, but can compute any
 //! order. Note that `jf` will attempt to fall back on `j` when it finds an integer order.
 //! 
 //! ```rust
@@ -70,17 +75,19 @@
 //! let res_2 = hankel_second(c, -2.3);
 //! ```
 //! 
+//! # Spherical Bessel functions
+//! 
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-use std::f64::consts::{                 // Calling constants
-    PI,
-    FRAC_PI_2
+use std::f64::consts::{     // Using std lib constants
+    PI,                     // Pi
+    FRAC_PI_2               // Pi / 2
 };
 
-use super::{                           // Calling sub-modules
-    basic,
-    complex::Complex
+use super::{                // Using parts from the crate
+    basic,                  // Basic functions
+    complex::Complex        // Using Complex numbers
 };
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -93,11 +100,15 @@ const DISTANCE_Y_LIM: f64 = 0.001;
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-/// # J Bessel function, integer index
+/// # $J$ Bessel function, integer index
 ///
 /// `x` is the value to evaluate, and `n` the order of the function.
 /// 
-/// The J Bessel represent the first kind of Bessel function, and are solution to Bessel differential equation.
+/// The $J$ Bessel represent the first kind of Bessel function, and are solution to Bessel differential equation,
+/// and is defined as follows:
+/// $$
+/// J_\alpha(x) = \sum_{m=0}^{\infty}\frac{(-1)^m}{m!\Gamma(m+\alpha+1)}\left( \frac{x}{2} \right)^{2p+\alpha}
+/// $$
 /// 
 /// The bessel function depend on an infinite sum of terms; which we can't have.
 /// The criterion chosen here is check each new term impacts the results significantly enough.
@@ -159,7 +170,7 @@ pub fn j<T: Into<Complex>>(x: T, n: i32) -> Complex {
         res += term;
 
         // If the changed compared to the final value is small we break
-        if (term / res).modulus().abs() < PRECISION_CONVERGENCE {
+        if (term / res).modulus() < PRECISION_CONVERGENCE {
             break 'convergence;
         }
 
@@ -177,10 +188,14 @@ pub fn j<T: Into<Complex>>(x: T, n: i32) -> Complex {
     }
 }
 
-/// # J Bessel function, real index
+/// # $J$ Bessel function, real index
 ///
 /// `x` is the value to evaluate, and `n` the order of the function.
 /// 
+/// $$
+/// J_\alpha(x) = \sum_{m=0}^{\infty}\frac{(-1)^m}{m!\Gamma(m+\alpha+1)}\left( \frac{x}{2} \right)^{2p+\alpha}
+/// $$
+/// 
 /// Similar to the other J Bessel method, but this one allows the use of a real (float) index, rather
 /// than an integer. This method is more costly to use than the other, and thus isn't recommended for
 /// integer orders. The function tries to prevent this by trying to fall back on the integer order version
@@ -231,7 +246,7 @@ pub fn jf<T, U>(x: T, order: U) -> Complex
     let mut res: Complex = Complex::default();  // The result of the operation
     
     // If the first term is already too small we exit directly
-    if term.modulus().abs() < PRECISION_CONVERGENCE {
+    if term.modulus() < PRECISION_CONVERGENCE {
         return res;
     }
 
@@ -240,7 +255,7 @@ pub fn jf<T, U>(x: T, order: U) -> Complex
         res += term;
 
         // If the changed compared to the final value is small we break
-        if (term / res).modulus().abs() < PRECISION_CONVERGENCE {
+        if (term / res).modulus() < PRECISION_CONVERGENCE {
             break 'convergence;
         }
 
@@ -258,8 +273,11 @@ pub fn jf<T, U>(x: T, order: U) -> Complex
 
 /// # Y Bessel function, real index
 /// 
-/// The Y Bessel represent the second kind of Bessel function, and are solution to Bessel differential equation,
-/// in the case of a singularity at the origin.
+/// The $Y$ Bessel represent the second kind of Bessel function, and are solution to Bessel differential equation,
+/// in the case of a singularity at the origin. It is defined as:
+/// $$
+/// Y_\alpha(x) = \frac{J_\alpha(x)\cos(\alpha\pi) - J_\alpha(x)}{\sin(\alpha\pi)}
+/// $$
 /// 
 /// `x` is the value to evaluate, and `n` the order of the function.
 /// 
@@ -306,24 +324,34 @@ where T: Into<Complex> + Copy, U: Into<f64> {
     }
 }
 
-/// # I modified Bessel function
+/// # $I$ modified Bessel function
 /// 
-/// The I modified First Bessel function represent another kind of solution to the Bessel differential equation.
+/// The $I$ modified First Bessel function represent another kind of solution to the Bessel differential equation.
 /// 
 /// `x` is the value to evaluate, and `n` the order of the function.
 /// 
-/// We use a definition of I based on an infinite series (similar to J). This way, we ensure good precision in
-/// the computation.
+/// We use a definition of I based on an infinite series (similar to $J$). This way, we ensure good precision in
+/// the computation, by following the definition:
+/// $$
+/// I_\alpha = i^{-\alpha}J_\alpha(ix)=\sum_{m=0}^{\infty}\frac{1}{m!\Gamma(m+\alpha+1)}\left( \frac{x}{2} \right)^{2m+\alpha}
+/// $$
 /// 
 /// ```
 /// # use scilib::math::complex::Complex;
-/// # use scilib::math::bessel::i;
+/// # use scilib::math::bessel::{i, jf};
 /// let res = i(1.2, 0);
 /// assert!((res.re - 1.39373).abs() < 1.0e-4 && res.im == 0.0);
 /// 
 /// let c = Complex::from(-1.2, 0.5);
 /// let r2 = i(c, -1.6);
 /// assert!((r2.re - 0.549831).abs() < 1.0e-5 && (r2.im - -0.123202).abs() < 1.0e-5);
+/// 
+/// // We can check that the values are coherent
+/// let val = Complex::from(3.2, -1.1);
+/// let resi = i(val, 1.2);
+/// let conf = jf(Complex::i() * val, 1.2) * Complex::i().powf(-1.2);
+/// assert!((resi.re - conf.re).abs() < 1.0e-14);
+/// assert!((resi.im - conf.im).abs() < 1.0e-14);
 /// ```
 pub fn i<T, U>(x: T, order: U) -> Complex
 where T: Into<Complex>, U: Into<f64> + Copy {
@@ -339,7 +367,7 @@ where T: Into<Complex>, U: Into<f64> + Copy {
     let mut res: Complex = Complex::default();  // The result of the operation
     
     // If the first term is already too small we exit directly
-    if term.modulus().abs() < PRECISION_CONVERGENCE {
+    if term.modulus() < PRECISION_CONVERGENCE {
         return res;
     }
 
@@ -348,7 +376,7 @@ where T: Into<Complex>, U: Into<f64> + Copy {
         res += term;
 
         // If the changed compared to the final value is small we break
-        if (term / res).modulus().abs() < PRECISION_CONVERGENCE {
+        if (term / res).modulus() < PRECISION_CONVERGENCE {
             break 'convergence;
         }
 
@@ -361,13 +389,16 @@ where T: Into<Complex>, U: Into<f64> + Copy {
     res
 }
 
-/// # K modified Bessel function
+/// # $K$ modified Bessel function
 /// 
-/// The K modified Second Bessel function represent another kind of solution to the Bessel differential equation.
+/// The $K$ modified Second Bessel function represent another kind of solution to the Bessel differential equation.
 /// 
 /// `x` is the value to evaluate, and `n` the order of the function.
 /// 
-/// The definition of K is similar to Y, but is based on I and not J.
+/// The definition of $K$ is similar to $Y$, but is based on $I$ and not $J$:
+/// $$
+/// K_\alpha(x) = \frac{\pi}{2}\frac{I_{-\alpha}(x) - I_\alpha(x)}{\sin(\alpha\pi)}
+/// $$
 /// 
 /// ```
 /// # use scilib::math::complex::Complex;
@@ -394,11 +425,12 @@ where T: Into<Complex> + Copy, U: Into<f64> {
     }
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
 /// # First Hankel function: H1
 /// 
-/// Computes the first kind of Hankel function, accepts complex input.
+/// Computes the first kind of Hankel function, which is defined as:
+/// $$
+/// H_\alpha^{(1)}(x) = J_\alpha(x) + iY_\alpha(x)
+/// $$
 /// 
 /// ```
 /// # use scilib::math::complex::Complex;
@@ -423,8 +455,10 @@ where T: Into<Complex> + Copy, U: Into<f64> {
 
 /// # Second Hankel function: H2
 /// 
-/// Computes the second kind of Hankel function, accepts complex input.
-/// We simplify the computation by simply conjugating the first kind
+/// Computes the first kind of Hankel function, which is defined as:
+/// $$
+/// H_\alpha^{(2)}(x) = J_\alpha(x) - iY_\alpha(x)
+/// $$
 /// 
 /// ```
 /// # use scilib::math::complex::Complex;
@@ -447,3 +481,318 @@ where T: Into<Complex> + Copy, U: Into<f64> {
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+/// # First spherical Bessel function: $j$
+/// 
+/// We follow the definition based on the $J$ Bessel functions:
+/// $$
+/// j_n(x) = \sqrt{\frac{\pi}{2x}}J_{n+\frac{1}{2}}(x)
+/// $$
+/// 
+/// Compute the first kind of spherical bessel function.
+/// * `z` - where the function is evaluated
+/// * `n` - order evaluated
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sj(Complex::from(13, 5), 3);
+/// assert!((res.re - 1.6109825049200244).abs() < 1e-8 && (res.im + 4.322382277910797).abs() < 1e-8);
+/// ```
+pub fn sj<T>(z: T, n: usize) -> Complex 
+where T: Into<Complex> {
+    let x: Complex  = z.into();
+    (FRAC_PI_2 / x).sqrt() * jf(x, n as f64 + 0.5)
+}
+
+fn sj_upward_recurrence<T>(z: T, n: usize) -> Vec<Complex> 
+where T: Into<Complex> {
+
+    let count = n + 1;
+    let x: Complex = z.into();
+    let mut jn = vec![Complex::new(); count];
+
+    jn[0] = x.sin() / x;
+    jn[1] = x.sin() / x.powi(2) - x.cos() / x;
+
+    for i in 1..=count - 2 {
+        jn[i + 1] = (2 * i + 1) as f64 / x * jn[i] - jn[i - 1];
+    }
+
+    jn
+}
+
+fn sj_downward_recurrence<T>(z: T, nl: usize, nu: usize) -> Vec<Complex> 
+where T: Into<Complex> {
+
+    let count = nu - nl + 1;
+    let x: Complex = z.into();
+    let mut jn= vec![Complex::new(); count + 2];
+
+    jn[count + 1] = Complex::new();
+    jn[count] = Complex::unity();
+
+    for i in (1..=count).rev() {
+        jn[i - 1] = (2 * i + 1) as f64 / x * jn[i] - jn[i + 1];
+    }
+    jn.resize(count, Complex::new());
+
+    jn
+}
+
+/// # First spherical Bessel function (array): j
+/// 
+/// Computes the first kind of spherical bessel function by recurrence to get an array of function.
+/// * `z` - where the function is evaluated
+/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sj[0]` to `sj[n]`
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res1 = sj_array(Complex::from(13, 5), 3);
+/// assert_eq!(res1[0], Complex::from(3.8248700377925635, 3.708547263317134));
+/// assert_eq!(res1[1], Complex::from(-3.357143112679857, 3.9747696875545517));
+/// assert_eq!(res1[2], Complex::from(-4.1924320794482135, -2.6499227040139104));
+/// 
+/// let res2 = sj_array(0.2, 25);
+/// assert_eq!(res2[13], Complex::from(3.835110596379198e-24, 0.0));
+/// assert_eq!(res2[17], Complex::from(5.910455642760406e-33, 0.0));
+/// assert_eq!(res2[25], Complex::from(1.125476749298975e-51, 0.0));
+/// 
+/// // We can also confirm the coherence of the results:
+/// let val = Complex::from(3.2, -1.1);
+/// let resj = sj(val, 3);
+/// let resa = sj_array(val, 3);
+/// assert!((resj.re - resa[3].re).abs() < 1.0e-6);
+/// assert!((resj.im - resa[3].im).abs() < 1.0e-6);
+/// ```
+pub fn sj_array<T>(z: T, n: usize) -> Vec<Complex>
+where T: Into<Complex> {
+
+    let x: Complex = z.into();
+
+    if x.modulus() > n as f64 / 2.0 {
+        return sj_upward_recurrence(x, n);
+    }
+
+    const PACK: usize = 50;
+    let num_big_loop = n / PACK;
+    let mut jn_all = Vec::<Vec<Complex>>::new();
+
+    for i in 0..num_big_loop {
+        jn_all.push(sj_downward_recurrence(x, i * PACK, (i + 1) * PACK));
+    }
+
+    let rest = n % PACK;
+    if rest != 0 {
+        jn_all.push(sj_downward_recurrence(x, n - rest, n));
+    }
+
+    let mut jn = Vec::<Complex>::with_capacity(n);
+    let mut norm = x.sin() / x / jn_all[0][0];
+
+    for i in 0..jn_all[0].len() {
+        jn.push(jn_all[0][i] * norm);
+    }
+
+    for i in 1..jn_all.len() {
+        norm = *jn.last().unwrap() / jn_all[i][0];
+        for k in 1..jn_all[i].len() {
+            jn.push(jn_all[i][k] * norm);
+        }
+    }
+    
+    jn
+}
+
+/// # Second spherical Bessel function: $y$
+/// 
+/// We follow the definition based on the $Y$ Bessel functions:
+/// $$
+/// y_n(x) = \sqrt{\frac{\pi}{2x}}Y_{n+\frac{1}{2}}(x)
+/// $$
+/// 
+/// Compute the second kind of spherical bessel function.
+/// * `z` - where the function is evaluated
+/// * `n` - order evaluated
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sy(Complex::from(13, 5), 3);
+/// assert!((res.re - 4.322629120777188).abs() < 1e-8 && (res.im - 1.6104674841102558) < 1e-8);
+/// ```
+pub fn sy<T>(z: T, n: usize) -> Complex 
+where T: Into<Complex> {
+    let x: Complex = z.into();
+    (FRAC_PI_2 / x).sqrt() * y(x, n as f64 + 0.5)
+}
+
+/// # Second spherical Bessel function (array): y
+/// 
+/// Computes the second kind of spherical bessel function by recurrence to get an array of function.
+/// * `z` - where the function is evaluated
+/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sy[0]` to `sy[n]`
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res1 = sy_array(Complex::from(13, 5), 3);
+/// assert_eq!(res1[0], Complex::from(-3.7090299518957797, 3.8248379131516654));
+/// assert_eq!(res1[1], Complex::from(-3.9748349852610523, -3.356650136356049));
+/// assert_eq!(res1[2], Complex::from(2.6504303824601, -4.1922958025278));
+/// let res2 = sy_array(0.2, 25);
+/// 
+/// assert_eq!(res2[13], Complex::from(-4.82921204481494e22, 0.0));
+/// assert_eq!(res2[17], Complex::from(-2.417182573235861e31, 0.0));
+/// assert_eq!(res2[25], Complex::from(-8.711173815326792e49, 0.0));
+/// 
+/// // We can also confirm the coherence of the results:
+/// let val = Complex::from(3.2, -1.1);
+/// let resj = sy(val, 3);
+/// let resa = sy_array(val, 3);
+/// assert!((resj.re - resa[3].re).abs() < 1.0e-6);
+/// assert!((resj.im - resa[3].im).abs() < 1.0e-6);
+/// ```
+pub fn sy_array<T>(z: T, n: usize) -> Vec<Complex>
+where T: Into<Complex> {
+
+    let x: Complex = z.into();
+    let y0 = -x.cos() / x;
+
+    if n == 0 {
+        return vec![y0];
+    }
+
+    let y1 = -x.cos() / (x * x) - x.sin() / x;
+
+    if n == 1 {
+        return vec![y0, y1];
+    }
+
+    let mut yn: Vec<Complex> = vec![Complex::new(); n + 1];
+    yn[0] = y0;
+    yn[1] = y1;
+
+    for i in 1..=n - 1 {
+        yn[i + 1] = ((2 * i + 1) as f64) / x * yn[i] - yn[i - 1];
+    }
+
+    yn
+}
+
+/// # First spherical Hankel function: h1
+/// 
+/// The first spherical hankel function is defined as:
+/// $$
+/// h_n^{(1)}(x) = j_n(x) + iy_n(x)
+/// $$
+/// 
+/// Compute the first kind of spherical hankel function.
+/// * `z` - where the function is evaluated
+/// * `n` - order evaluated
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sh_first(Complex::from(13, 5), 3);
+/// assert!((res.re - 5.150208097686182e-4).abs() < 1e-8 && (res.im - 2.4684286639153896e-4).abs() < 1e-8);
+/// ```
+pub fn sh_first<T>(z: T, n: usize) -> Complex 
+where T: Into<Complex> {
+    let x: Complex = z.into();
+    sj(x, n) + Complex::i() * sy(x, n)
+}
+
+/// # First spherical Hankel function (array): h1
+/// 
+/// Compute the first kind of spherical hankel function by recurrence to get an array of function.
+/// * `z` - where the function is evaluated
+/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sh_first[0]` to `sh_first[n]`
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sh_first_array(Complex::from(13, 5), 3);
+/// assert_eq!(res[3], Complex::from(5.127390110655217e-4, 2.5295761378174575e-4));
+/// 
+/// // We can also confirm the coherence of the results:
+/// let val = Complex::from(3.2, -1.1);
+/// let resj = sh_first(val, 3);
+/// let resa = sh_first_array(val, 3);
+/// assert!((resj.re - resa[3].re).abs() <= 1.0e-5);
+/// assert!((resj.im - resa[3].im).abs() <= 1.0e-6);
+/// ```
+pub fn sh_first_array<T>(z: T, n: usize) -> Vec<Complex> 
+where T: Into<Complex> {
+
+    let x: Complex = z.into();
+    let sj_res = sj_array(x, n);
+    let sy_res = sy_array(x, n);
+    let mut sh_first = Vec::<Complex>::with_capacity(n + 1);
+
+    for i in 0..sj_res.len() {
+        sh_first.push(sj_res[i] + Complex::i() * sy_res[i]);
+    }
+
+    sh_first
+}
+
+/// # Second spherical Hankel function: h2
+/// 
+/// The second spherical hankel function is defined as:
+/// $$
+/// h_n^{(2)}(x) = j_n(x) - iy_n(x)
+/// $$
+/// 
+/// Compute the second kind of spherical hankel function.
+/// * `z` - where the function is evaluated
+/// * `n` - order evaluated
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sh_second(Complex::from(13, 5), 3);
+/// assert!((res.re - 3.22144998903028).abs() < 1e-8 && (res.im + 8.645011398687984).abs() < 1e-8);
+/// ```
+pub fn sh_second<T>(z: T, n: usize) -> Complex 
+where T: Into<Complex> {
+    let x: Complex = z.into();
+    sj(x, n) - Complex::i() * sy(x, n)
+}
+
+/// # Second spherical Hankel function (array): h2
+/// 
+/// Compute the second kind of spherical hankel function by recurrence to get an array of function.
+/// * `z` - where the function is evaluated
+/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sh_second[0]` to `sh_second[n]`
+/// 
+/// ```
+/// # use scilib::math::complex::Complex;
+/// # use scilib::math::bessel::*;
+/// let res = sh_second_array(Complex::from(13, 5), 3);
+/// assert_eq!(res[3], Complex::from(3.2214420145498694, -8.644990000503286));
+/// 
+/// // We can also confirm the coherence of the results:
+/// let val = Complex::from(3.2, -1.1);
+/// let resj = sh_second(val, 3);
+/// let resa = sh_second_array(val, 3);
+/// assert!((resj.re - resa[3].re).abs() < 1.0e-6);
+/// assert!((resj.im - resa[3].im).abs() < 1.0e-6);
+/// ```
+pub fn sh_second_array<T>(z: T, n: usize) -> Vec<Complex> 
+where T: Into<Complex> {
+
+    let x: Complex = z.into();
+    let sj_res = sj_array(x, n);
+    let sy_res = sy_array(x, n);
+    let mut sh_second = Vec::<Complex>::with_capacity(n + 1);
+
+    for i in 0..sj_res.len() {
+        sh_second.push(sj_res[i] - Complex::i() * sy_res[i]);
+    }
+    
+    sh_second
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
